@@ -18,33 +18,40 @@ import org.scilab.forge.scirenderer.implementation.jogl.buffers.JoGLBuffersManag
 import org.scilab.forge.scirenderer.implementation.jogl.depthtest.JoGLDepthBufferManager;
 import org.scilab.forge.scirenderer.implementation.jogl.picking.JoGLPickingManager;
 import org.scilab.forge.scirenderer.implementation.jogl.renderer.JoGLRendererManager;
-import org.scilab.forge.scirenderer.implementation.jogl.sprite.JoGLSpriteManager;
 import org.scilab.forge.scirenderer.implementation.jogl.texture.JoGLTextureManager;
 import org.scilab.forge.scirenderer.picking.PickingManager;
 
-import javax.media.opengl.DebugGL;
-import javax.media.opengl.GL;
-import javax.media.opengl.GLAutoDrawable;
-import javax.media.opengl.GLEventListener;
+import com.jogamp.opengl.util.awt.Screenshot;
 import java.awt.Dimension;
+import java.awt.image.BufferedImage;
+import javax.media.opengl.DebugGL2;
+import javax.media.opengl.GL2;
+import javax.media.opengl.GLAutoDrawable;
+import javax.media.opengl.GLCapabilities;
+import javax.media.opengl.GLContext;
+import javax.media.opengl.GLDrawableFactory;
+import javax.media.opengl.GLEventListener;
+import javax.media.opengl.GLPbuffer;
+import javax.media.opengl.GLProfile;
 
 /**
  * JoGL implementation of a Canvas.
  *
  * @author Pierre Lando
  */
-public class JoGLCanvas implements Canvas, GLEventListener {
+public final class JoGLCanvas implements Canvas, GLEventListener {
 
     private final GLAutoDrawable autoDrawable;
 
     private final JoGLDrawingTools drawingTools;
     private final JoGLParameters parameters;
-    private final JoGLSpriteManager spriteManager;
     private final JoGLBuffersManager buffersManager;
     private final JoGLRendererManager rendererManager;
     private final JoGLDepthBufferManager depthBufferManager;
     private final JoGLPickingManager pickingManager;
     private final JoGLTextureManager textureManager;
+    private boolean isOffscreen;
+    private DebugGL2 debug;
 
 
     /**
@@ -59,7 +66,6 @@ public class JoGLCanvas implements Canvas, GLEventListener {
     JoGLCanvas(GLAutoDrawable autoDrawable) {
         this.autoDrawable = autoDrawable;
         parameters = new JoGLParameters();
-        spriteManager = new JoGLSpriteManager(this);
         buffersManager = new JoGLBuffersManager();
         rendererManager = new JoGLRendererManager();
         depthBufferManager = new JoGLDepthBufferManager();
@@ -70,6 +76,24 @@ public class JoGLCanvas implements Canvas, GLEventListener {
         autoDrawable.addGLEventListener(this);
     }
 
+    /**
+     * Constructor for offscreen rendering
+     * @param width the width
+     * @param height the height
+     */
+    JoGLCanvas(int width, int height) {
+        this(getOffscreenDrawable(width, height));
+        isOffscreen = true;
+    }
+
+    public void setDebugMode(boolean debug) {
+        if (debug) {
+            this.debug = new DebugGL2(autoDrawable.getGL().getGL2());
+        } else {
+            this.debug = null;
+        }
+    }
+
     // Implementation of getter & setter from Canvas.
 
     @Override
@@ -82,11 +106,6 @@ public class JoGLCanvas implements Canvas, GLEventListener {
         return mainDrawer;
     }
 
-    @Override
-    public JoGLSpriteManager getSpriteManager() {
-        return spriteManager;
-    }
-
     @Override
     public JoGLRendererManager getRendererManager() {
         return rendererManager;
@@ -129,27 +148,21 @@ public class JoGLCanvas implements Canvas, GLEventListener {
 
     @Override
     public void redraw() {
-        autoDrawable.repaint();
+        autoDrawable.display();
     }
 
-
     // JoGLCanvas specific getter.
 
     /**
      * Return the OpenGl context.
      * @return the OpenGl context.
      */
-    public GL getGl() {
-        return new DebugGL(autoDrawable.getGL());
-        //return autoDrawable.getGL();
-    }
-
-    /**
-     * Package method to get the sprite manager.
-     * @return the sprite manager.
-     */
-    JoGLSpriteManager getJoGLSpriteManager() {
-        return spriteManager;
+    public GL2 getGl() {
+        if (debug == null) {
+            return autoDrawable.getGL().getGL2();
+        } else {
+            return debug;
+        }
     }
 
     /**
@@ -160,23 +173,55 @@ public class JoGLCanvas implements Canvas, GLEventListener {
         return parameters;
     }
 
+    /**
+     * Get an image from the autoDrawable
+     * @return an image
+     */
+    public BufferedImage getImage() {
+        GLContext context = autoDrawable.getContext();
+        context.makeCurrent();
+        BufferedImage image = Screenshot.readToBufferedImage(autoDrawable.getWidth(), autoDrawable.getHeight());
+        context.release();
+
+        return image;
+    }
+
+    /**
+     * Destroy the GLPbuffer
+     */
+    public void destroy() {
+        if (isOffscreen) {
+            ((GLPbuffer) autoDrawable).destroy();
+        }
+    }
+
+    /**
+     * Creates a GLPbuffer for an offscreen rendering
+     * @param width the width
+     * @param height the height
+     * @return a GLPbuffer
+     */
+    private static GLAutoDrawable getOffscreenDrawable(int width, int height) {
+        GLDrawableFactory factory = GLDrawableFactory.getDesktopFactory();
+        GLCapabilities capabilities = new GLCapabilities(GLProfile.getDefault());
+
+        return factory.createGLPbuffer(null, capabilities, null, width, height, null);
+    }
 
     // Implementation of function from GLEventListener.
 
     @Override
     public void display(GLAutoDrawable glAutoDrawable) {
-        GL gl = getGl();
-
+        GL2 gl = getGl().getGL2();
         drawingTools.glSynchronize(gl);
         buffersManager.glSynchronize(gl);
         rendererManager.glSynchronize(gl);
-        spriteManager.glSynchronize(drawingTools);
 
         if (mainDrawer != null) {
-            gl.glEnable(GL.GL_DEPTH_TEST); // TODO add possibility to (de-)activate depth test.
-            gl.glDepthFunc(GL.GL_LEQUAL); // Set to less equal to allow last drawn object to be on the top.
+            gl.glEnable(GL2.GL_DEPTH_TEST); // TODO add possibility to (de-)activate depth test.
+            gl.glDepthFunc(GL2.GL_LEQUAL); // Set to less equal to allow last drawn object to be on the top.
             if (depthBufferManager.isAutoClearDepthBufferEnable()) {
-                gl.glClear(GL.GL_DEPTH_BUFFER_BIT);
+                gl.glClear(GL2.GL_DEPTH_BUFFER_BIT);
             }
 
             mainDrawer.draw(drawingTools);
@@ -186,19 +231,19 @@ public class JoGLCanvas implements Canvas, GLEventListener {
 
     @Override
     public void init(GLAutoDrawable glAutoDrawable) {
-        GL gl = getGl();
-
-        drawingTools.glSynchronize(gl);
-        buffersManager.glReload(gl);
+        textureManager.glReload();
+        buffersManager.glReload();
         rendererManager.glReload();
-        spriteManager.glReload(drawingTools);
     }
 
     @Override
     public void reshape(GLAutoDrawable glAutoDrawable, int x, int y, int width, int height) {
     }
 
-    @Override
+    //@Override
     public void displayChanged(GLAutoDrawable glAutoDrawable, boolean b, boolean b1) {
     }
+
+    @Override
+    public void dispose(GLAutoDrawable drawable) { }
 }
