@@ -17,11 +17,11 @@ import org.scilab.forge.scirenderer.buffers.BuffersManager;
 import org.scilab.forge.scirenderer.buffers.ElementsBuffer;
 import org.scilab.forge.scirenderer.ruler.graduations.Graduations;
 import org.scilab.forge.scirenderer.shapes.appearance.Appearance;
-import org.scilab.forge.scirenderer.shapes.geometry.Geometry;
 import org.scilab.forge.scirenderer.shapes.geometry.DefaultGeometry;
-import org.scilab.forge.scirenderer.sprite.Sprite;
-import org.scilab.forge.scirenderer.sprite.SpriteAnchorPosition;
-import org.scilab.forge.scirenderer.sprite.SpriteManager;
+import org.scilab.forge.scirenderer.shapes.geometry.Geometry;
+import org.scilab.forge.scirenderer.texture.AnchorPosition;
+import org.scilab.forge.scirenderer.texture.Texture;
+import org.scilab.forge.scirenderer.texture.TextureManager;
 import org.scilab.forge.scirenderer.tranformations.Transformation;
 import org.scilab.forge.scirenderer.tranformations.Vector3d;
 
@@ -41,12 +41,12 @@ public class RulerDrawer {
     /**
      * Sprite map.
      */
-    private final Map<Double, Sprite> spriteMap = new ConcurrentHashMap<Double, Sprite>();
+    private final Map<Double, Texture> spriteMap = new ConcurrentHashMap<Double, Texture>();
 
     /**
-     * The current {@link SpriteManager}.
+     * The current {@link TextureManager}.
      */
-    private final SpriteManager spriteManager;
+    private final TextureManager textureManager;
 
     /**
      * The used {@link RulerSpriteFactory}.
@@ -55,10 +55,10 @@ public class RulerDrawer {
 
     /**
      * Ruler drawer constructor.
-     * @param spriteManager the {@link SpriteManager} of the canvas where the ruler will be drawn.
+     * @param textureManager the {@link TextureManager} of the canvas where the ruler will be drawn.
      */
-    public RulerDrawer(SpriteManager spriteManager) {
-        this.spriteManager = spriteManager;
+    public RulerDrawer(TextureManager textureManager) {
+        this.textureManager = textureManager;
         this.spriteFactory = new DefaultRulerSpriteFactory();
     }
 
@@ -87,7 +87,7 @@ public class RulerDrawer {
      * Dispose all used resources.
      */
     public void disposeResources() {
-        spriteManager.dispose(spriteMap.values());
+        textureManager.dispose(spriteMap.values());
         spriteMap.clear();
     }
 
@@ -103,12 +103,12 @@ public class RulerDrawer {
         private final Vector3d windowSubTicksDelta;
         private final Vector3d windowTicksDelta;
 
-        private List<PositionedSprite> spritesList = new LinkedList<PositionedSprite>();
+        private final List<PositionedSprite> spritesList = new LinkedList<PositionedSprite>();
 
         /**
          * The maximum distance corresponding to the actually displayed sprites.
          */
-        private double maximalSpritesDistance = 0.0;
+        private double maximalSpritesDistance;
 
         /**
          * Deepest possible {@see Graduations}
@@ -124,8 +124,8 @@ public class RulerDrawer {
          * @param drawingTools the {@link DrawingTools} of the canvas where the ruler will be drawn.
          * @param rulerModel the {@link RulerModel} of the drawn ruler.
          */
-        public OneShotRulerDrawer (DrawingTools drawingTools, RulerModel rulerModel) {
-            this.rulerModel =rulerModel;
+        public OneShotRulerDrawer(DrawingTools drawingTools, RulerModel rulerModel) {
+            this.rulerModel = rulerModel;
             canvasProjection = drawingTools.getTransformationManager().getCanvasProjection();
 
             Vector3d windowTicksDirection = canvasProjection.projectDirection(rulerModel.getTicksDirection());
@@ -133,7 +133,7 @@ public class RulerDrawer {
 
             Vector3d normalizedProjectedTicksDirection = windowTicksDirection.getNormalized();
             windowSubTicksDelta = normalizedProjectedTicksDirection.times(rulerModel.getSubTicksLength());
-            windowTicksDelta = normalizedProjectedTicksDirection.times(rulerModel.getSpriteDistance());
+            windowTicksDelta = normalizedProjectedTicksDirection.times(rulerModel.getTicksLength());
 
             if (rulerModel.isAutoTicks()) {
                 computeAutoGraduation();
@@ -190,10 +190,10 @@ public class RulerDrawer {
             appearance.setLineWidth(1);
 
             drawingTools.getTransformationManager().useWindowCoordinate();
-            for (PositionedSprite positionedSprite : spritesList) {
-                drawingTools.draw(positionedSprite.getSprite(), SpriteAnchorPosition.CENTER, positionedSprite.getWindowPosition());
-            }
             try {
+                for (PositionedSprite positionedSprite : spritesList) {
+                    drawingTools.draw(positionedSprite.getSprite(), AnchorPosition.CENTER, positionedSprite.getWindowPosition());
+                }
                 drawingTools.draw(geometry, appearance);
             } catch (SciRendererException ignored) {
             }
@@ -206,7 +206,7 @@ public class RulerDrawer {
          */
         private void computeAutoGraduation() {
             /* The maximum distance corresponding to the actually displayed sprites. */
-            double maximalSpritesDistance = 0.0;
+            double maxSpritesDistance = 0.0;
 
             Graduations currentGraduations = rulerModel.getGraduations();
             Graduations ticksGraduation = currentGraduations;
@@ -219,7 +219,7 @@ public class RulerDrawer {
                 List<PositionedSprite> newSpritesList = new LinkedList<PositionedSprite>();
                 List<Double> ticks = currentGraduations.getNewValues();
                 for (double value : ticks) {
-                    Sprite sprite = computeSprite(value, currentGraduations.getFormat());
+                    Texture sprite = computeSprite(value, currentGraduations.getFormat());
                     Vector3d windowPosition = canvasProjection.project(rulerModel.getPosition(value));
 
                     Vector3d delta = projectCenterToEdge(sprite, windowTicksDelta);
@@ -233,7 +233,7 @@ public class RulerDrawer {
                     currentGraduations = currentGraduations.getAlternative();
                     canGetMore = false;
                 } else {
-                    maximalSpritesDistance = Math.max(maximalSpritesDistance, currentMaximalSpritesDistance);
+                    maxSpritesDistance = Math.max(maxSpritesDistance, currentMaximalSpritesDistance);
                     spritesList.addAll(newSpritesList);
                     ticksGraduation = currentGraduations;
                     if (canGetMore) {
@@ -245,7 +245,7 @@ public class RulerDrawer {
             }
 
             this.graduations = ticksGraduation;
-            this.maximalSpritesDistance = maximalSpritesDistance;
+            this.maximalSpritesDistance = maxSpritesDistance;
         }
 
         /**
@@ -253,12 +253,12 @@ public class RulerDrawer {
          */
         private void computeUserGraduation() {
             /* The maximum distance corresponding to the actually displayed sprites. */
-            double maximalSpritesDistance = 0.0;
+            double maxSpritesDistance = 0.0;
             Graduations currentGraduations = rulerModel.getGraduations();
 
             List<Double> ticks = currentGraduations.getNewValues();
             for (double value : ticks) {
-                Sprite sprite = computeSprite(value, currentGraduations.getFormat());
+                Texture sprite = computeSprite(value, currentGraduations.getFormat());
                 if (sprite != null) {
                     Vector3d windowPosition = canvasProjection.project(rulerModel.getPosition(value));
 
@@ -266,12 +266,12 @@ public class RulerDrawer {
                     spritesList.add(new PositionedSprite(sprite, windowPosition.plus(windowTicksDelta.plus(delta))));
 
                     Vector3d farDelta = windowTicksDelta.plus(delta.times(2.0));
-                    maximalSpritesDistance = Math.max(maximalSpritesDistance, farDelta.getNorm());
+                    maxSpritesDistance = Math.max(maxSpritesDistance, farDelta.getNorm());
                 }
             }
 
             this.graduations = currentGraduations;
-            this.maximalSpritesDistance = maximalSpritesDistance;
+            this.maximalSpritesDistance = maxSpritesDistance;
         }
 
         /**
@@ -330,7 +330,7 @@ public class RulerDrawer {
          */
         private boolean collide(List<PositionedSprite> spritesList, double margin) {
             for (int i = 0; i < spritesList.size(); i++) {
-                for (int j = i + 1; j <spritesList.size(); j++) {
+                for (int j = i + 1; j < spritesList.size(); j++) {
                     if (collide(spritesList.get(i).getWindowBounds(), spritesList.get(j).getWindowBounds(), margin)) {
                         return true;
                     }
@@ -375,18 +375,22 @@ public class RulerDrawer {
          * Compute and return a translation along the given <code>direction</code>.
          * This translation is the vector between the <code>sprite</code> center and is projection along the given
          * {@see direction} to the sprite edges.
-         * @param sprite the given {@link Sprite}
+         * @param sprite the given {@link Texture}
          * @param direction the given direction.
          * @return the vector between the sprite center and is projection to the sprite edges.
          */
-        private Vector3d projectCenterToEdge(Sprite sprite, Vector3d direction) {
+        private Vector3d projectCenterToEdge(Texture sprite, Vector3d direction) {
+            Vector3d usedDirection;
             if ((direction == null) || (direction.isZero())) {
-                direction = new Vector3d(1, 0, 0);
+                usedDirection = new Vector3d(1, 0, 0);
+            } else {
+                usedDirection = direction;
             }
-            double ratioX = sprite.getWidth() / Math.abs(direction.getX());
-            double ratioY = sprite.getHeight() / Math.abs(direction.getY());
+
+            double ratioX = sprite.getDataProvider().getTextureSize().width / Math.abs(usedDirection.getX());
+            double ratioY = sprite.getDataProvider().getTextureSize().height / Math.abs(usedDirection.getY());
             double ratio = Math.min(ratioY, ratioX) / 2;
-            return direction.times(ratio);
+            return usedDirection.times(ratio);
         }
 
 
@@ -435,72 +439,72 @@ public class RulerDrawer {
         }
 
         /**
-         * Compute the {@link Sprite} for a given value.
-         * The {@link Sprite} is made once using the current {@link RulerSpriteFactory}.
+         * Compute the {@link Texture} for a given value.
+         * The {@link Texture} is made once using the current {@link RulerSpriteFactory}.
          * @param value the given value.
          * @param format the format to use.
-         * @return A {@link Sprite} for the label at the given value.
+         * @return A {@link Texture} for the label at the given value.
          */
-        private Sprite computeSprite(double value, DecimalFormat format) {
-            Sprite sprite = spriteMap.get(value);
+        private Texture computeSprite(double value, DecimalFormat format) {
+            Texture sprite = spriteMap.get(value);
             if (sprite == null) {
-                sprite = spriteFactory.create(value, format, spriteManager);
+                sprite = spriteFactory.create(value, format, textureManager);
                 spriteMap.put(value, sprite);
             }
             return sprite;
         }
 
         /**
-         * This class is a basic container for a {@link Sprite} and an associated window position.
+         * This class is a basic container for a {@link Texture} and an associated window position.
          *
          * @author Pierre Lando
          */
         private class PositionedSprite {
 
-            private final Sprite sprite;
+            private final Texture sprite;
             private final Vector3d windowPosition;
             private final Rectangle2D windowsBounds;
 
             /**
              * Default constructor.
-             * @param sprite the {@link Sprite}.
+             * @param sprite the {@link Texture}.
              * @param windowPosition the window position.
              */
-            public PositionedSprite(Sprite sprite,  Vector3d windowPosition) {
+            public PositionedSprite(Texture sprite,  Vector3d windowPosition) {
                 this.windowPosition = windowPosition;
                 this.sprite = sprite;
 
                 windowsBounds = new Rectangle2D.Double(
                         windowPosition.getX(),
                         windowPosition.getY(),
-                        sprite.getWidth(),
-                        sprite.getHeight()
+                        sprite.getDataProvider().getTextureSize().width,
+                        sprite.getDataProvider().getTextureSize().height
                 );
             }
 
             /**
-             * Return the {@link Sprite}
-             * @return the {@link Sprite}
+             * Return the {@link Texture}
+             * @return the {@link Texture}
              */
-            public Sprite getSprite() {
+            public Texture getSprite() {
                 return sprite;
             }
 
             /**
-             * Return the window position of the {@link Sprite}.
-             * @return the window position of the {@link Sprite}.
+             * Return the window position of the {@link Texture}.
+             * @return the window position of the {@link Texture}.
              */
             public Vector3d getWindowPosition() {
                 return windowPosition;
             }
 
             /**
-             * Return the window bounds of the {@link Sprite}
-             * @return the window bounds of the {@link Sprite}
+             * Return the window bounds of the {@link Texture}
+             * @return the window bounds of the {@link Texture}
              */
             public Rectangle2D getWindowBounds() {
                 return windowsBounds;
             }
         }
     }
-}
\ No newline at end of file
+}
